@@ -12,7 +12,4 @@ class ProcessPool(object):
     def _create_processes(self):
         for i in range(0, self.process_count):
             process = Process(target=self.func, args=[self.queue])
-            process.start()
-            
-    def handle_accept(self):
-        self.queue.put(True)
\ No newline at end of file
+            process.start()
\ No newline at end of file
